@@ -211,7 +211,7 @@ int snd_ctl_poll_descriptors_revents(snd_ctl_t *ctl, struct pollfd *pfds, unsign
 }
 
 /**
- * \brief Ask to be informed about events (poll, #snd_ctl_async, #snd_ctl_read)
+ * \brief Ask to be informed about events (poll, #snd_async_add_ctl_handler, #snd_ctl_read)
  * \param ctl CTL handle
  * \param subscribe 0 = unsubscribe, 1 = subscribe
  * \return 0 on success otherwise a negative error code
@@ -674,8 +674,8 @@ int snd_ctl_read(snd_ctl_t *ctl, snd_ctl_event_t *event)
 int snd_ctl_wait(snd_ctl_t *ctl, int timeout)
 {
 	struct pollfd *pfd;
-	unsigned short *revents;
-	int i, npfds, pollio, err, err_poll;
+	unsigned short revents;
+	int i, npfds, err, err_poll;
 
 	npfds = snd_ctl_poll_descriptors_count(ctl);
 	if (npfds <= 0 || npfds >= 16) {
@@ -683,7 +683,6 @@ int snd_ctl_wait(snd_ctl_t *ctl, int timeout)
 		return -EIO;
 	}
 	pfd = alloca(sizeof(*pfd) * npfds);
-	revents = alloca(sizeof(*revents) * npfds);
 	err = snd_ctl_poll_descriptors(ctl, pfd, npfds);
 	if (err < 0)
 		return err;
@@ -691,26 +690,20 @@ int snd_ctl_wait(snd_ctl_t *ctl, int timeout)
 		SNDMSG("invalid poll descriptors %d\n", err);
 		return -EIO;
 	}
-	do {
+	for (;;) {
 		err_poll = poll(pfd, npfds, timeout);
 		if (err_poll < 0)
 			return -errno;
 		if (! err_poll)
-			break;
-		err = snd_ctl_poll_descriptors_revents(ctl, pfd, npfds, revents);
+			return 0;
+		err = snd_ctl_poll_descriptors_revents(ctl, pfd, npfds, &revents);
 		if (err < 0)
 			return err;
-		pollio = 0;
-		for (i = 0; i < npfds; i++) {
-			if (revents[i] & (POLLERR | POLLNVAL))
-				return -EIO;
-			if ((revents[i] & (POLLIN | POLLOUT)) == 0)
-				continue;
-			pollio++;
-		}
-	} while (! pollio);
-
-	return err_poll > 0 ? 1 : 0;
+		if (revents & (POLLERR | POLLNVAL))
+			return -EIO;
+		if (revents & (POLLIN | POLLOUT))
+			return 1;
+	}
 }
 
 /**
@@ -757,7 +750,7 @@ snd_ctl_t *snd_async_handler_get_ctl(snd_async_handler_t *handler)
 	return handler->u.ctl;
 }
 
-static const char *build_in_ctls[] = {
+static const char *const build_in_ctls[] = {
 	"hw", "shm", NULL
 };
 
@@ -842,7 +835,7 @@ static int snd_ctl_open_conf(snd_ctl_t **ctlp, const char *name,
 		sprintf(buf, "_snd_ctl_%s_open", str);
 	}
 	if (!lib) {
-		const char **build_in = build_in_ctls;
+		const char *const *build_in = build_in_ctls;
 		while (*build_in) {
 			if (!strcmp(*build_in, str))
 				break;
@@ -952,7 +945,7 @@ int snd_ctl_open_lconf(snd_ctl_t **ctlp, const char *name,
 #define IFACE1(v, n) [SND_CTL_ELEM_IFACE_##v] = #n
 #define EVENT(v) [SND_CTL_EVENT_##v] = #v
 
-static const char *snd_ctl_elem_type_names[] = {
+static const char *const snd_ctl_elem_type_names[] = {
 	TYPE(NONE),
 	TYPE(BOOLEAN),
 	TYPE(INTEGER),
@@ -962,7 +955,7 @@ static const char *snd_ctl_elem_type_names[] = {
 	TYPE(INTEGER64),
 };
 
-static const char *snd_ctl_elem_iface_names[] = {
+static const char *const snd_ctl_elem_iface_names[] = {
 	IFACE(CARD),
 	IFACE(HWDEP),
 	IFACE(MIXER),
@@ -972,7 +965,7 @@ static const char *snd_ctl_elem_iface_names[] = {
 	IFACE(SEQUENCER),
 };
 
-static const char *snd_ctl_event_type_names[] = {
+static const char *const snd_ctl_event_type_names[] = {
 	EVENT(ELEM),
 };
 #endif
